@@ -11,7 +11,7 @@ ANY WARRANTY WHATSOEVER.
 
 Check the License for details. You should have received a copy of it, along
 with the package; see the file 'COPYING'. If not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
+Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA. */
 
 #include "pari.h"
 #include "paripriv.h"
@@ -1337,7 +1337,7 @@ GEN
 Flx_gcd(GEN x, GEN y, ulong p)
 {
   pari_sp av = avma, lim = stack_lim(av,2);
-  if (!lgpol(y)) { return vecsmall_copy(x); }
+  if (!lgpol(x)) return vecsmall_copy(y);
   while (lg(y)>Flx_GCD_LIMIT)
   {
     GEN c;
