@@ -11,7 +11,7 @@ ANY WARRANTY WHATSOEVER.
 
 Check the License for details. You should have received a copy of it, along
 with the package; see the file 'COPYING'. If not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
+Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA. */
 
 #include "pari.h"
 #include "paripriv.h"
@@ -208,7 +208,7 @@ Flm_Fl_mul_inplace(GEN y, ulong x, ulong p)
     for(j=1; j<l; j++)
       for(i=1; i<m; i++) ucoeff(y,i,j) = (ucoeff(y,i,j) * x) % p;
 }
-/* set y = x * y */
+/* return x * y */
 GEN
 Flm_Fl_mul(GEN y, ulong x, ulong p)
 {
@@ -224,7 +224,7 @@ Flm_Fl_mul(GEN y, ulong x, ulong p)
       GEN c = cgetg(m, t_VECSMALL); gel(z,j) = c;
       for(i=1; i<m; i++) c[i] = (ucoeff(y,i,j) * x) % p;
     }
-  return y;
+  return z;
 }
 
 /* x[i,]*y. Assume lx > 1 and 0 < i < lg(x[1]) */
