@@ -11,7 +11,7 @@ ANY WARRANTY WHATSOEVER.
 
 Check the License for details. You should have received a copy of it, along
 with the package; see the file 'COPYING'. If not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
+Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA. */
 
 #include "pari.h"
 #include "paripriv.h"
@@ -519,7 +519,7 @@ FpX_gcd_basecase(GEN a, GEN b, GEN p)
 GEN
 FpX_gcd(GEN x, GEN y, GEN p)
 {
-  pari_sp av = avma, av0;
+  pari_sp av = avma;
   if (lgefint(p)==3)
   {
     ulong pp = p[2];
@@ -529,9 +529,9 @@ FpX_gcd(GEN x, GEN y, GEN p)
     x = Flx_gcd(x,y, pp);
     avma = av; return Flx_to_ZX(x);
   }
-  x = FpX_red(x, p); av0 = avma;
+  x = FpX_red(x, p);
   y = FpX_red(y, p);
-  if (!signe(y)) { avma = av0; return x; }
+  if (!signe(x)) return gerepileupto(av, y);
   while (lg(y)>FpX_GCD_LIMIT)
   {
     GEN c;
