@@ -11,7 +11,7 @@ ANY WARRANTY WHATSOEVER.
 
 Check the License for details. You should have received a copy of it, along
 with the package; see the file 'COPYING'. If not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
+Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA. */
 
 /**************************************************************/
 /*                                                            */
@@ -915,7 +915,7 @@ idealfrobenius(GEN nf, GEN gal, GEN pr)
   GEN S=NULL, g=NULL; /*-Wall*/
   GEN T, p, a, b, modpr;
   long f, n, s;
-  checknf(nf);
+  nf = checknf(nf);
   checkgal(gal);
   checkprid(pr);
   if (!gequal(nf_get_pol(nf), gal_get_pol(gal)))
@@ -1056,7 +1056,7 @@ idealramgroups(GEN nf, GEN gal, GEN pr)
   GEN tbl, idx, res, set, sub;
   long i, j, e, n, maxm, p;
   ulong et;
-  checknf(nf);
+  nf = checknf(nf);
   checkgal(gal);
   checkprid(pr);
   if (!gequal(nf_get_pol(nf), gal_get_pol(gal)))
@@ -2067,7 +2067,11 @@ polred_aux(nfbasic_t *T, GEN *pro, long flag)
     GEN ch, ai = gel(T->bas,i);
     ch = get_polmin_w(&d, i);
     /* if accuracy too low, compute algebraically */
-    if (!ch) ch = ZXQ_charpoly(ai, x, v);
+    if (!ch)
+    {
+      ch = ZXQ_charpoly(ai, x, v);
+      (void)ZX_gcd_all(ch, ZX_deriv(ch), &ch);
+    }
     if (ZX_canon_neg(ch) && orig) ai = RgX_neg(ai);
     if (nfred && degpol(ch) == l-1) return mkvec2(ch, ai);
     if (DEBUGLEVEL>3) err_printf("polred: generator %Ps\n", ch);
