@@ -10,7 +10,7 @@ Foundation. It is distributed in the hope that it will be useful, but WITHOUT
 ANY WARRANTY WHATSOEVER.
 Check the License for details. You should have received a copy of it, along
 with the package; see the file 'COPYING'. If not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
+Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA. */
 
 /*******************************************************************/
 /*                                                                 */
@@ -2417,6 +2417,7 @@ Rg_to_ff(GEN nf, GEN x, GEN modpr)
       x = Q_remove_denom(x, &den);
       if (lg(x) == lg(nf_get_zk(nf))) break;
     default: pari_err(typeer,"Rg_to_ff");
+      return NULL; /* NOT REACHED */
   }
   if (den)
   {
