@@ -11,7 +11,7 @@ ANY WARRANTY WHATSOEVER.
 
 Check the License for details. You should have received a copy of it, along
 with the package; see the file 'COPYING'. If not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
+Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA. */
 
 #include "pari.h"
 #include "paripriv.h"
@@ -224,7 +224,7 @@ polhermite(long n, long v)
       av = avma;
       a = diviuexact(muliu(a, (n-2*m+2)*(n-2*m+1)), 4*m);
       togglesign(a);
-      gel(r--,0) = gerepileuptoint(av, a);
+      gel(r--,0) = a = gerepileuptoint(av, a);
       gel(r--,0) = gen_0;
     }
   else
@@ -233,7 +233,7 @@ polhermite(long n, long v)
       av = avma;
       a = diviuexact(mulii(a, muluu(n-2*m+2, n-2*m+1)), 4*m);
       togglesign(a);
-      gel(r--,0) = gerepileuptoint(av, a);
+      gel(r--,0) = a = gerepileuptoint(av, a);
       gel(r--,0) = gen_0;
     }
   q[1] = evalsigne(1) | evalvarn(v);
@@ -680,27 +680,27 @@ GEN
 dirmul(GEN x, GEN y)
 {
   pari_sp av = avma, lim = stack_lim(av, 1);
-  long lx, ly, lz, dx, dy, i, j, k;
+  long nx, ny, nz, dx, dy, i, j, k;
   GEN z;
 
   if (typ(x)!=t_VEC || typ(y)!=t_VEC) pari_err(typeer,"dirmul");
-  dx = dirval(x); lx = lg(x);
-  dy = dirval(y); ly = lg(y);
-  if (ly-dy < lx-dx) { swap(x,y); lswap(lx,ly); lswap(dx,dy); }
-  lz = minss(lx*dy,ly*dx);
-  z = zerovec(lz-1);
-  for (j=dx; j<lx; j++)
+  dx = dirval(x); nx = lg(x)-1;
+  dy = dirval(y); ny = lg(y)-1;
+  if (ny-dy < nx-dx) { swap(x,y); lswap(nx,ny); lswap(dx,dy); }
+  nz = minss(nx*dy,ny*dx);
+  z = zerovec(nz);
+  for (j=dx; j<=nx; j++)
   {
     GEN c = gel(x,j);
     if (gequal0(c)) continue;
     if (gequal1(c))
-      for (k=dy,i=j*dy; i<lz; i+=j,k++) gel(z,i) = gadd(gel(z,i),gel(y,k));
+      for (k=dy,i=j*dy; i<=nz; i+=j,k++) gel(z,i) = gadd(gel(z,i),gel(y,k));
     else
     {
       if (gequalm1(c))
-        for (k=dy,i=j*dy; i<lz; i+=j,k++) gel(z,i) = gsub(gel(z,i),gel(y,k));
+        for (k=dy,i=j*dy; i<=nz; i+=j,k++) gel(z,i) = gsub(gel(z,i),gel(y,k));
       else
-        for (k=dy,i=j*dy; i<lz; i+=j,k++) gel(z,i) = gadd(gel(z,i),gmul(c,gel(y,k)));
+        for (k=dy,i=j*dy; i<=nz; i+=j,k++) gel(z,i) = gadd(gel(z,i),gmul(c,gel(y,k)));
     }
     if (low_stack(lim, stack_lim(av,1)))
     {
@@ -715,28 +715,28 @@ GEN
 dirdiv(GEN x, GEN y)
 {
   pari_sp av = avma;
-  long lx,ly,lz,dx,dy,i,j;
+  long nx,ny,nz,dx,dy,i,j;
   GEN z,p1;
 
   if (typ(x)!=t_VEC || typ(y)!=t_VEC) pari_err(typeer,"dirmul");
-  dx = dirval(x); lx = lg(x);
-  dy = dirval(y); ly = lg(y);
-  if (dy != 1 || ly == 1) pari_err(talker,"not an invertible dirseries in dirdiv");
-  lz = minss(lx,ly*dx); p1 = gel(y,1);
+  dx = dirval(x); nx = lg(x)-1;
+  dy = dirval(y); ny = lg(y)-1;
+  if (dy != 1 || !ny) pari_err(talker,"not an invertible dirseries in dirdiv");
+  nz = minss(nx,ny*dx); p1 = gel(y,1);
   if (!gequal1(p1)) { y = gdiv(y,p1); x = gdiv(x,p1); } else x = leafcopy(x);
-  z = zerovec(lz-1);
-  for (j=dx; j<lz; j++)
+  z = zerovec(nz);
+  for (j=dx; j<=nz; j++)
   {
     p1=gel(x,j); gel(z,j) = p1;
     if (gequal0(p1)) continue;
     if (gequal1(p1))
-      for (i=j+j; i<lz; i+=j) gel(x,i) = gsub(gel(x,i),gel(y,i/j));
+      for (i=j+j; i<=nz; i+=j) gel(x,i) = gsub(gel(x,i),gel(y,i/j));
     else
     {
       if (gequalm1(p1))
-        for (i=j+j; i<lz; i+=j) gel(x,i) = gadd(gel(x,i),gel(y,i/j));
+        for (i=j+j; i<=nz; i+=j) gel(x,i) = gadd(gel(x,i),gel(y,i/j));
       else
-        for (i=j+j; i<lz; i+=j) gel(x,i) = gsub(gel(x,i),gmul(p1,gel(y,i/j)));
+        for (i=j+j; i<=nz; i+=j) gel(x,i) = gsub(gel(x,i),gmul(p1,gel(y,i/j)));
     }
   }
   return gerepilecopy(av,z);
@@ -1394,12 +1394,12 @@ vecsort0(GEN x, GEN k, long flag)
   int (*CMP)(void*,GEN,GEN);
   int (*cmp)(GEN,GEN) = (flag & cmp_LEX)? &lexcmp: &gcmp;
   void *E;
+  struct veccmp_s v;
 
   if (flag < 0 || flag > (cmp_REV|cmp_LEX|cmp_IND|cmp_UNIQ))
     pari_err(flagerr,"vecsort");
   if (k) {
     long i, j, l, lk, tx, lx;
-    struct veccmp_s v;
     GEN y;
 
     /* cf init_sort */
