@@ -11,7 +11,7 @@ ANY WARRANTY WHATSOEVER.
 
 Check the License for details. You should have received a copy of it, along
 with the package; see the file 'COPYING'. If not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
+Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA. */
 
 /*******************************************************************/
 /*                                                                 */
@@ -1588,7 +1588,7 @@ Discrayrel(GEN bnr, GEN H0, long flag)
 {
   pari_sp av = avma;
   long j, k, l, nz, flrel = flag & rnf_REL, flcond = flag & rnf_COND;
-  GEN bnf, nf, bid, ideal, archp, clhray, clhss, P, e, dlk, H;
+  GEN bnf, nf, bid, ideal, archp, clhray, clhss, P, e, dlk;
   zlog_S S;
 
   checkbnr(bnr);
@@ -1597,7 +1597,7 @@ Discrayrel(GEN bnr, GEN H0, long flag)
   clhray = bnr_get_no(bnr);
   nf = bnf_get_nf(bnf);
   ideal= bid_get_ideal(bid);
-  H0 = H = check_subgroup(bnr, H0, &clhray, 0, "bnrdiscray");
+  H0 = check_subgroup(bnr, H0, &clhray, 0, "bnrdiscray");
   archp = S.archp;
   P     = S.P;
   e     = S.e; l = lg(e);
@@ -1605,7 +1605,7 @@ Discrayrel(GEN bnr, GEN H0, long flag)
              : powii(ZM_det_triangular(ideal),clhray);
   for (k = 1; k < l; k++)
   {
-    GEN pr = gel(P,k), sum = gen_0;
+    GEN pr = gel(P,k), sum = gen_0, H = H0;
     long ep = itos(gel(e,k));
     for (j = ep; j > 0; j--)
     {
