@@ -11,7 +11,7 @@ ANY WARRANTY WHATSOEVER.
 
 Check the License for details. You should have received a copy of it, along
 with the package; see the file 'COPYING'. If not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
+Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA. */
 
 #include "pari.h"
 #include "paripriv.h"
@@ -331,11 +331,11 @@ matrixnorm(GEN M, long prec)
 }
 
 static GEN
-galoisborne(GEN T, GEN dn, struct galois_borne *gb)
+galoisborne(GEN T, GEN dn, struct galois_borne *gb, long d)
 {
   pari_sp ltop = avma, av2;
   GEN borne, borneroots, borneabs;
-  long n, prec;
+  long prec;
   GEN L, M, prep, den;
   pari_timer ti;
 
@@ -347,8 +347,7 @@ galoisborne(GEN T, GEN dn, struct galois_borne *gb)
   if (DEBUGLEVEL>=4) timer_printf(&ti,"vandermondeinverse");
   borne = matrixnorm(M, prec);
   borneroots = gsupnorm(L, prec); /*t_REAL*/
-  n = degpol(T);
-  borneabs = addsr(1, gmulsg(n, powru(borneroots, n)));
+  borneabs = addsr(1, gmul(borne,gmulsg(d, powru(borneroots, d))));
   borneroots = addsr(1, gmul(borne, borneroots));
   av2 = avma;
   /*We use d-1 test, so we must overlift to 2^BITS_IN_LONG*/
@@ -683,9 +682,11 @@ frobeniusliftall(GEN sg, long el, GEN *psi, struct galois_lift *gl,
       Ni++; i = 0;
       if (DEBUGLEVEL>=4) timer_start(&ti);
     }
-    for (j = 2; j < m && pf[j-1] >= pf[j]; j++);
+    for (j = 2; j < m && pf[j-1] >= pf[j]; j++)
+      /*empty*/; /* to kill clang Warning */
     for (k = 1; k < j-k && pf[k] != pf[j-k]; k++) { lswap(pf[k], pf[j-k]); }
-    for (k = j - 1; pf[k] >= pf[j]; k--);
+    for (k = j - 1; pf[k] >= pf[j]; k--)
+      /*empty*/;
     lswap(pf[j], pf[k]); c_idx = j;
   }
   if (DEBUGLEVEL>=4) err_printf("GaloisConj: not found, %d hops \n",hop);
@@ -1302,7 +1303,7 @@ galoisanalysis(GEN T, struct galois_analysis *ga, long calcul_l)
   ga->ord = order;
   ga->primepointer = pp;
   ga->l  = O[1];
-  ga->p4 = O[4];
+  ga->p4 = n >= 4 ? O[4] : 0;
   if (DEBUGLEVEL >= 4)
     err_printf("GaloisAnalysis:p=%ld l=%ld group=%ld deg=%ld ord=%ld\n",
                plift, O[1], group, deg, order);
@@ -1377,7 +1378,6 @@ a4galoisgen(struct galois_test *td)
         ar[1] = ar[2] + mael(MT,t[4],t[5]);
         break;
       case 11:
-        y = 10;
         x = t[0]; t[0] = t[8]; t[8] = t[7]; t[7] = t[5]; t[5] = t[1];
         t[1] = t[6]; t[6] = t[3]; t[3] = t[2]; t[2] = t[4]; t[4] = x;
         lswap(t[10], t[10-a]);
@@ -1967,7 +1967,7 @@ galoisgenfixedfield(GEN Tp, GEN Pmod, GEN V, GEN ip, struct galois_borne *gb, GE
     long j;
     if (!galoisanalysis(P, &Pga, 0)) return NULL;
     Pgb.l = gb->l;
-    Pden = galoisborne(P, NULL, &Pgb);
+    Pden = galoisborne(P, NULL, &Pgb, degpol(P));
 
     if (Pgb.valabs > gb->valabs)
     {
@@ -2219,7 +2219,7 @@ galoisconj4_main(GEN T, GEN den, long flag)
   }
   gb.l = utoipos(ga.l);
   if (DEBUGLEVEL >= 1) timer_start(&ti);
-  den = galoisborne(T, den, &gb);
+  den = galoisborne(T, den, &gb, degpol(T));
   if (DEBUGLEVEL >= 1) timer_printf(&ti, "galoisborne()");
   L = rootpadicfast(T, gb.l, gb.valabs);
   if (DEBUGLEVEL >= 1) timer_printf(&ti, "rootpadicfast()");
@@ -2335,7 +2335,7 @@ isomborne(GEN P, GEN den, GEN p)
 {
   pari_sp av = avma;
   struct galois_borne gb;
-  gb.l = p; (void)galoisborne(P,den,&gb);
+  gb.l = p; (void)galoisborne(P,den,&gb,degpol(P));
   avma = av; return gb.valsol;
 }
 
@@ -2497,14 +2497,14 @@ galoisfixedfield(GEN gal, GEN perm, long flag, long y)
     struct galois_borne Pgb;
     long val = itos(gal_get_e(gal));
     Pgb.l = gal_get_p(gal);
-    Pden = galoisborne(P, NULL, &Pgb);
+    Pden = galoisborne(P, NULL, &Pgb, degpol(T)/degpol(P));
     if (Pgb.valabs > val)
     {
       if (DEBUGLEVEL>=4)
         err_printf("GaloisConj:increase p-adic prec by %ld.\n", Pgb.valabs-val);
       PL = ZpX_liftroots(P, PL, Pgb.l, Pgb.valabs);
       L  = ZpX_liftroots(T, L, Pgb.l, Pgb.valabs);
-      mod = Pgb.ladicabs;
+      mod = Pgb.ladicabs; mod2 = shifti(mod,-1);
     }
     PM = vandermondeinversemod(PL, P, Pden, mod);
     if (y < 0) y = fetch_user_var("y");
