@@ -11,7 +11,7 @@ ANY WARRANTY WHATSOEVER.
 
 Check the License for details. You should have received a copy of it, along
 with the package; see the file 'COPYING'. If not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
+Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA. */
 
 /********************************************************************/
 /**                                                                **/
@@ -751,6 +751,11 @@ gidentical(GEN x, GEN y)
 
     case t_COMPLEX:
       return gidentical(gel(x,2),gel(y,2)) && gidentical(gel(x,1),gel(y,1));
+    case t_PADIC:
+      return valp(x) == valp(y)
+        && equalii(gel(x,2),gel(y,2))
+        && equalii(gel(x,3),gel(y,3))
+        && equalii(gel(x,4),gel(y,4));
     case t_POLMOD:
       return gidentical(gel(x,2),gel(y,2)) && polidentical(gel(x,1),gel(y,1));
     case t_POL:
@@ -792,7 +797,6 @@ gidentical(GEN x, GEN y)
   }
   return 0;
 }
-
 /* x,y t_POL */
 static int
 polequal(GEN x, GEN y)
@@ -860,6 +864,10 @@ gequal(GEN x, GEN y)
 
       case t_COMPLEX:
         return gequal(gel(x,2),gel(y,2)) && gequal(gel(x,1),gel(y,1));
+      case t_PADIC:
+        if (!equalii(gel(x,2),gel(y,2))) return 0;
+        av = avma; i = gequal0(gsub(x,y)); avma = av;
+        return i;
       case t_POLMOD:
         return gequal(gel(x,2),gel(y,2)) && RgX_equal_var(gel(x,1),gel(y,1));
       case t_POL:
@@ -880,8 +888,13 @@ gequal(GEN x, GEN y)
             && gequal(gel(x,3),gel(y,3));
 
       case t_RFRAC:
-        av=avma; i=gequal(gmul(gel(x,1),gel(y,2)),gmul(gel(x,2),gel(y,1)));
-        avma=av; return i;
+      {
+        GEN a = gel(x,1), b = gel(x,2), c = gel(y,1), d = gel(y,2);
+        if (gequal(b,d)) return gequal(a,c); /* simple case */
+        av = avma;
+        i = gequal(simplify_shallow(gmul(a,d)), simplify_shallow(gmul(b,c)));
+        avma = av; return i;
+      }
 
       case t_STR:
         return !strcmp(GSTR(x),GSTR(y));
@@ -2398,8 +2411,9 @@ listput(GEN L, GEN x, long index)
     l++;
   } else
     gunclone_deep( gel(z, index) );
-  z[0] = evaltyp(t_VEC) | evallg(l);
-  return gel(z,index) = gclone(x);
+  gel(z,index) = gclone(x);
+  z[0] = evaltyp(t_VEC) | evallg(l); /*must be after gel(z,index) is set*/
+  return gel(z,index);
 }
 
 GEN
