@@ -11,7 +11,7 @@ ANY WARRANTY WHATSOEVER.
 
 Check the License for details. You should have received a copy of it, along
 with the package; see the file 'COPYING'. If not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
+Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA. */
 
 /********************************************************************/
 /**                                                                **/
@@ -511,7 +511,7 @@ modr_safe(GEN x, GEN y)
   q = gdiv(x,y); /* t_REAL */
 
   e = expo(q);
-  if (e >= 0 && nbits2prec(e) > lg(x)) return NULL;
+  if (e >= 0 && nbits2prec(e) > lg(q)) return NULL;
   f = floorr(q);
   if (gsigne(y) < 0 && signe(subri(q,f))) f = addis(f, 1);
   return signe(f)? gsub(x, mulir(f,y)): x;
@@ -1286,7 +1286,7 @@ gsubst(GEN x, long v, GEN y)
   long tx = typ(x), ty = typ(y), lx = lg(x), ly = lg(y);
   long l, vx, vy, e, ex, ey, i, j, k, jb;
   pari_sp av, av2, lim;
-  GEN X, t, p1, p2, z;
+  GEN X, t, p1, p2, modp1, z;
 
   switch(ty)
   {
@@ -1313,9 +1313,18 @@ gsubst(GEN x, long v, GEN y)
     if (typ(p1)!=t_POL)
       pari_err(talker,"forbidden substitution in a scalar type");
     if (varncmp(vy, vx) >= 0) return gerepileupto(av, gmodulo(p2,p1));
+    modp1 = mkpolmod(gen_1,p1);
     lx = lg(p2);
     z = cgetg(lx,t_POL); z[1] = p2[1];
-    for (i=2; i<lx; i++) gel(z,i) = gmodulo(gel(p2,i),p1);
+    for (i=2; i<lx; i++)
+    {
+      GEN c = gel(p2,i);
+      if (varncmp(vx, gvar(c)) <= 0)
+        c = gmodulo(c,p1);
+      else
+        c = gmul(c, modp1);
+      gel(z,i) = c;
+    }
     return gerepileupto(av, normalizepol_lg(z,lx));
   }
 
@@ -1419,7 +1428,8 @@ gsubst(GEN x, long v, GEN y)
           return gerepileupto(av, gmul(z,p2));
 
         case t_POL:
-          if (lg(y) == 2) return scalarser(gel(x,2),v,lx-2);
+          if (lg(y) == 2)
+            return (lx == 2)? gcopy(x): scalarser(gel(x,2),v,lx-2);
         case t_RFRAC:
           vy = gvar(y); e = gval(y,vy);
           if (e <= 0)
@@ -1453,24 +1463,31 @@ GEN
 gsubstvec(GEN e, GEN v, GEN r)
 {
   pari_sp ltop=avma;
-  long i,l=lg(v);
-  GEN w,z;
-  if ( !is_vec_t(typ(v)) || !is_vec_t(typ(r)) )
-    pari_err(typeer,"substvec");
+  long i, j, l = lg(v);
+  GEN w, z, R;
+  if ( !is_vec_t(typ(v)) || !is_vec_t(typ(r)) ) pari_err(typeer,"substvec");
   if (lg(r)!=l)
     pari_err(talker,"different number of variables and values in substvec");
-  w=cgetg(l,t_VECSMALL);
-  z=cgetg(l,t_VECSMALL);
-  for(i=1;i<l;i++)
+  w = cgetg(l,t_VECSMALL);
+  z = cgetg(l,t_VECSMALL);
+  R = cgetg(l,t_VEC);
+  for(i=j=1;i<l;i++)
   {
-    GEN T = gel(v,i);
+    GEN T = gel(v,i), ri = gel(r,i);
     if (!gcmpX(T)) pari_err(talker,"not a variable in substvec (%Ps)", T);
-    w[i]=varn(T);
-    z[i]=fetch_var();
+    if (gvar(ri) == NO_VARIABLE) /* no need to take precautions */
+      e = gsubst(e, varn(T), ri);
+    else
+    {
+      w[j] = varn(T);
+      z[j] = fetch_var();
+      gel(R,j) = ri;
+      j++;
+    }
   }
-  for(i=1;i<l;i++) e = gsubst(e,w[i],pol_x(z[i]));
-  for(i=1;i<l;i++) e = gsubst(e,z[i],gel(r,i));
-  for(i=1;i<l;i++) (void)delete_var();
+  for(i=1;i<j;i++) e = gsubst(e,w[i],pol_x(z[i]));
+  for(i=1;i<j;i++) e = gsubst(e,z[i],gel(R,i));
+  for(i=1;i<j;i++) (void)delete_var();
   return gerepileupto(ltop,e);
 }
 
@@ -1665,7 +1682,9 @@ diffop(GEN x, GEN v, GEN dv)
       {
         GEN m = gel(x,1), pol=gel(x,2);
         GEN u = gneg(gdiv(diffop(m,v,dv),RgX_deriv(m)));
-        y = gadd(diffop(pol,v,dv), gmul(u,RgX_deriv(pol)));
+        y = diffop(pol,v,dv);
+        if (typ(pol)==t_POL && varn(pol)==varn(m))
+          y = gadd(y, gmul(u,RgX_deriv(pol)));
         y = gmodulo(y, gel(x,1));
       }
       return gerepileupto(av, y);
@@ -2051,9 +2070,8 @@ ground(GEN x)
       for (i=2; i<lx; i++) gel(y,i) = ground(gel(x,i));
       return normalize(y);
     case t_RFRAC:
-      y = cgetg(3, t_RFRAC);
-      gel(y,1) = ground(gel(x,1));
-      gel(y,2) = ground(gel(x,2)); return y;
+      av = avma;
+      return gerepileupto(av, gdiv(ground(gel(x,1)), ground(gel(x,2))));
     case t_VEC: case t_COL: case t_MAT:
       y = cgetg_copy(x, &lx);
       for (i=1; i<lx; i++) gel(y,i) = ground(gel(x,i));
@@ -3030,10 +3048,14 @@ lift0(GEN x, long v)
     case t_PADIC:
       return gtrunc(x);
 
-    case t_POL: case t_SER:
+    case t_POL:
       y = cgetg_copy(x, &lx); y[1] = x[1];
       for (i=2; i<lx; i++) gel(y,i) = lift0(gel(x,i), v);
-      return y;
+      return normalizepol_lg(y,lx);
+    case t_SER:
+      y = cgetg_copy(x, &lx); y[1] = x[1];
+      for (i=2; i<lx; i++) gel(y,i) = lift0(gel(x,i), v);
+      return normalize(y);
     case t_COMPLEX: case t_RFRAC:
     case t_VEC: case t_COL: case t_MAT:
       y = cgetg_copy(x, &lx);
