@@ -11,7 +11,7 @@ ANY WARRANTY WHATSOEVER.
 
 Check the License for details. You should have received a copy of it, along
 with the package; see the file 'COPYING'. If not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
+Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA. */
 
 /***********************************************************************/
 /**                                                                   **/
@@ -1365,35 +1365,53 @@ factormod0(GEN f, GEN p, long flag)
 /*                  CONVERSIONS RELATED TO p-ADICS                 */
 /*                                                                 */
 /*******************************************************************/
+/* x t_PADIC, p a prime. Consistency check */
+static void
+check_padic_p(GEN x, GEN p)
+{
+  GEN q = gel(x,2);
+  if (!equalii(p, q))
+    pari_err(talker, "different primes in Zp_to_Z: %Ps != %Ps", p, q);
+}
 static GEN
-Zp_to_Z(GEN x) {
+Zp_to_Z(GEN x, GEN p) {
   switch(typ(x))
   {
     case t_INT: break;
-    case t_PADIC: x = gtrunc(x); break;
-    default: pari_err(typeer,"QpX_to_ZX");
+    case t_PADIC:
+      check_padic_p(x, p);
+      x = gtrunc(x); break;
+    default: pari_err(typeer,"Zp_to_Z",x);
   }
   return x;
 }
 static GEN
-ZpX_to_ZX(GEN f) {
+ZpX_to_ZX(GEN f, GEN p) {
   long i, l = lg(f);
   GEN F = cgetg(l, t_POL); F[1] = f[1];
-  for (i=2; i<l; i++) gel(f,i) = Zp_to_Z(gel(f,i));
+  for (i=2; i<l; i++) gel(f,i) = Zp_to_Z(gel(f,i), p);
   return f;
 }
-/* make f suitable for [root|factor]padic */
+
 static GEN
-QpX_to_ZX(GEN f)
+get_padic_content(GEN f, GEN p)
 {
   GEN c = content(f);
   if (gequal0(c)) /*  O(p^n) can occur */
   {
-    if (typ(c) != t_PADIC) pari_err(typeer,"QpX_to_ZX");
-    c = powis(gel(c,2), valp(c));
+    if (typ(c) != t_PADIC) pari_err(typeer,"QpX_to_ZX",f);
+    check_padic_p(c, p);
+    c = powis(p, valp(c));
   }
-  f = RgX_Rg_div(f,c);
-  return ZpX_to_ZX(f);
+  return c;
+}
+/* make f suitable for [root|factor]padic */
+static GEN
+QpX_to_ZX(GEN f, GEN p)
+{
+  GEN c = get_padic_content(f, p);
+  f = RgX_Rg_div(f, c);
+  return ZpX_to_ZX(f, p);
 }
 
 /* x in Z return x + O(pr), pr = p^r. Return gen_0 instead of zeropadic */
@@ -1456,23 +1474,18 @@ ZXV_to_ZpXQV(GEN z, GEN T, GEN p, long prec)
 }
 
 static GEN
-QpXQ_to_ZXY(GEN f)
+QpXQ_to_ZXY(GEN f, GEN p)
 {
-  GEN c = content(f);
+  GEN c = get_padic_content(f, p);
   long i, l = lg(f);
-  if (gequal0(c)) /*  O(p^n) can occur */
-  {
-    if (typ(c) != t_PADIC) pari_err(typeer,"QpXQ_to_ZXY");
-    c = powis(gel(c,2), valp(c));
-  }
   f = RgX_Rg_div(f,c);
   for (i=2; i<l; i++)
   {
     GEN t = gel(f,i);
     switch(typ(t))
     {
-      case t_POL: t = ZpX_to_ZX(t); break;
-      default: t = Zp_to_Z(t); break;
+      case t_POL: t = ZpX_to_ZX(t, p); break;
+      default: t = Zp_to_Z(t, p); break;
     }
     gel(f,i) = t;
   }
@@ -1525,7 +1538,7 @@ Zp_appr(GEN f, GEN a)
   if (typ(f) != t_POL) pari_err(notpoler,"Zp_appr");
   if (typ(a) != t_PADIC) pari_err(typeer,"Zp_appr");
   p = gel(a,2); prec = gequal0(a)? valp(a): precp(a);
-  f = QpX_to_ZX(f);
+  f = QpX_to_ZX(f, p);
   if (degpol(f) <= 0) pari_err(constpoler,"Zp_appr");
   (void)ZX_gcd_all(f, ZX_deriv(f), &f);
   z = ZX_Zp_root(f, gtrunc(a), p, prec);
@@ -1584,7 +1597,7 @@ rootpadic(GEN f, GEN p, long prec)
   if (typ(f)!=t_POL) pari_err(notpoler,"rootpadic");
   if (gequal0(f)) pari_err(zeropoler,"rootpadic");
   if (prec <= 0) pari_err(talker,"non-positive precision in rootpadic");
-  f = QpX_to_ZX(f);
+  f = QpX_to_ZX(f, p);
   f = pnormalize(f, p, prec, 1, &lead, &PREC, &reverse);
   y = ZX_Zp_roots(f,p,PREC);
   k = lg(y);
@@ -1677,9 +1690,9 @@ padicappr(GEN f, GEN a)
   p = NULL; prec = LONG_MAX;
   getprec(a, &prec, &p);
   getprec(T, &prec, &p); if (!p) pari_err(typeer,"padicappr");
-  f = QpXQ_to_ZXY(lift_intern(f));
-  a = QpX_to_ZX(a);
-  T = QpX_to_ZX(T);
+  f = QpXQ_to_ZXY(f, p);
+  a = QpX_to_ZX(a,p);
+  T = QpX_to_ZX(T,p);
   z = ZXY_ZpQ_root(f, a, T, p, prec);
   return gerepilecopy(av, ZXV_to_ZpXQV(z, T, p, prec));
 }
@@ -1782,7 +1795,7 @@ factorpadic2(GEN f, GEN p, long prec)
 
   n = degpol(f);
   if (n==0) return trivfact();
-  f = QpX_to_ZX(f);
+  f = QpX_to_ZX(f, p);
   if (n==1) return gerepilecopy(av, padic_trivfact(f,p,prec));
   if (!gequal1(leading_term(f)))
     pari_err(impl,"factorpadic2 for non-monic polynomial");
@@ -1877,7 +1890,7 @@ factorpadic(GEN f,GEN p,long prec)
   if (prec <= 0) pari_err(talker,"non-positive precision in factorpadic");
   if (n == 0) return trivfact();
 
-  f = QpX_to_ZX(f); (void)Z_pvalrem(leading_term(f), p, &lt);
+  f = QpX_to_ZX(f, p); (void)Z_pvalrem(leading_term(f), p, &lt);
   f = pnormalize(f, p, prec, n-1, &lead, &pr, &reverse);
   y = ZX_monic_factorpadic(f, p, pr);
   P = gel(y,1); l = lg(P);
@@ -2326,7 +2339,12 @@ FqX_roots_i(GEN f, GEN T, GEN p)
   GEN R;
   f = FqX_normalize(f, T, p);
   if (!signe(f)) pari_err(zeropoler,"FqX_roots");
-  if (isabsolutepol(f)) return FpX_rootsff_i(simplify_shallow(f), p, T);
+  if (isabsolutepol(f))
+  {
+    f = simplify_shallow(f);
+    if (typ(f) == t_INT) return cgetg(1, t_COL);
+    return FpX_rootsff_i(f, p, T);
+  }
   if (degpol(f)==2)
     return gen_sort(FqX_quad_roots(f,T,p), (void*) &cmp_RgX, &cmp_nodata);
   switch( FqX_split_deg1(&R, f, powiu(p, degpol(T)), T, p) )
