@@ -11,7 +11,7 @@ ANY WARRANTY WHATSOEVER.
 
 Check the License for details. You should have received a copy of it, along
 with the package; see the file 'COPYING'. If not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
+Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA. */
 
 /***********************************************************************/
 /**                                                                   **/
@@ -2450,25 +2450,26 @@ static GEN
 fix_pol(GEN x, long v, long *mx)
 {
   long vx;
-  GEN p1;
-
-  if (typ(x) == t_POL)
+  if (typ(x) != t_POL) return x;
+  vx = varn(x);
+  if (v == vx)
   {
-    vx = varn(x);
-    if (vx)
-    {
-      if (v>=vx) return gsubst(x,v,pol_x(0));
-      p1 = cgetg(3,t_POL);
-      p1[1] = evalvarn(0)|evalsigne(signe(x));
-      gel(p1,2) = x; return p1;
-    }
-    if (v)
-    {
-      *mx = 1;
-      return gsubst(gsubst(x,0,pol_x(MAXVARN)),v,pol_x(0));
-    }
+    if (v) { x = leafcopy(x); setvarn(x, 0); }
+    return x;
   }
-  return x;
+  if (!vx)
+  {
+    *mx = 1;
+    x = poleval(x, pol_x(MAXVARN));
+    vx = varn(x);
+    if (v == vx) { setvarn(x, 0); return x; }
+  }
+  if (varncmp(v, vx) > 0)
+  {
+    x = gsubst(x,v,pol_x(0));
+    if (typ(x) == t_POL && varn(x) == 0) return x;
+  }
+  return scalarpol(x, 0);
 }
 
 /* resultant of x and y with respect to variable v, or with respect to their
@@ -2634,9 +2635,9 @@ inexact(GEN x, int *simple, int *rational)
 static GEN
 gcdmonome(GEN x, GEN y)
 {
+  pari_sp av = avma;
   long dx = degpol(x), e = RgX_valrem(y, &y);
   long i, l = lg(y);
-  pari_sp av = avma;
   GEN t, v = cgetg(l, t_VEC);
   gel(v,1) = gel(x,dx+2);
   for (i = 2; i < l; i++) gel(v,i) = gel(y,i);
