@@ -11,7 +11,7 @@ ANY WARRANTY WHATSOEVER.
 
 Check the License for details. You should have received a copy of it, along
 with the package; see the file 'COPYING'. If not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
+Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA. */
 
 /***********************************************************************/
 /**                                                                   **/
@@ -975,12 +975,8 @@ GEN
 Fq_neg(GEN x, GEN T/*unused*/, GEN p)
 {
   (void)T;
-  switch(typ(x)==t_POL)
-  {
-    case 0: return Fp_neg(x,p);
-    case 1: return FpX_neg(x,p);
-  }
-  return NULL;
+  return (typ(x)==t_POL)? FpX_neg(x,p)
+                        : Fp_neg(x,p);
 }
 
 /* If T==NULL do not reduce*/
