@@ -11,7 +11,7 @@ ANY WARRANTY WHATSOEVER.
 
 Check the License for details. You should have received a copy of it, along
 with the package; see the file 'COPYING'. If not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
+Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA. */
 
 /********************************************************************/
 /**                                                                **/
@@ -1135,24 +1135,36 @@ gsqrt(GEN x, long prec)
       gel(y,2) = p1; return y;
 
     case t_COMPLEX:
-      if (isrationalzero(gel(x,2))) return gsqrt(gel(x,1), prec);
+    { /* (u+iv)^2 = a+ib <=> u^2+v^2 = sqrt(a^2+b^2), u^2-v^2=a, 2uv=b */
+      GEN a = gel(x,1), b = gel(x,2), u, v;
+      if (isrationalzero(b)) return gsqrt(a, prec);
       y = cgetg(3,t_COMPLEX); av = avma;
 
-      p1 = gsqrt(cxnorm(x), prec);
+      p1 = cxnorm(x);
       if (typ(p1) == t_INTMOD) pari_err(impl,"sqrt(complex of t_INTMODs)");
-      if (!signe(p1)) { gel(y,1) = gel(y,2) = sqrtr(p1); return y; }
-      if (gsigne(gel(x,1)) < 0)
+      p1 = gsqrt(p1, prec); /* t_REAL */
+      if (!signe(p1))
+        u = v = gerepileuptoleaf(av, sqrtr(p1));
+      else if (gsigne(a) < 0)
       {
-        p1 = sqrtr( gmul2n(gsub(p1,gel(x,1)), -1) );
-        if (gsigne(gel(x,2)) < 0) togglesign(p1);
-        gel(y,2) = gerepileuptoleaf(av, p1); av = avma;
-        gel(y,1) = gerepileuptoleaf(av, gdiv(gel(x,2), gmul2n(p1,1)));
+        p1 = sqrtr( gmul2n(gsub(p1,a), -1) );
+        if (gsigne(b) < 0) togglesign(p1);
+        v = gerepileuptoleaf(av, p1); av = avma;
+        if (!signe(p1)) /* possible if a = 0 */
+          u = v;
+        else
+          u = gerepileuptoleaf(av, gdiv(b, shiftr(v,1)));
       } else {
-        p1 = sqrtr( gmul2n(gadd(p1,gel(x,1)), -1) );
-        gel(y,1) = gerepileuptoleaf(av, p1); av = avma;
-        gel(y,2) = gerepileuptoleaf(av, gdiv(gel(x,2), gmul2n(p1,1)));
+        p1 = sqrtr( gmul2n(gadd(p1,a), -1) );
+        u = gerepileuptoleaf(av, p1); av = avma;
+        if (!signe(p1)) /* possible if a = 0 */
+          v = u;
+        else
+          v = gerepileuptoleaf(av, gdiv(b, shiftr(u,1)));
       }
-      return y;
+      gel(y,1) = u;
+      gel(y,2) = v; return y;
+    }
 
     case t_PADIC:
       return Qp_sqrt(x);
@@ -1262,22 +1274,35 @@ Qp_sqrtn_ram(GEN x, long e)
 {
   pari_sp ltop=avma;
   GEN a, p = gel(x,2), n = powiu(p,e);
-  long v = valp(x);
+  long v = valp(x), va;
   if (v)
   {
     long z;
     v = sdivsi_rem(v, n, &z);
     if (z) return NULL;
-    x = gcopy(x); setvalp(x,0);
+    x = leafcopy(x);
+    setvalp(x,0);
+  }
+  /*If p = 2, -1 is a root of 1 in U1: need extra check*/
+  if (equaliu(p, 2) && mod8(gel(x,4)) != 1) return NULL;
+  a = Qp_log(x);
+  va = valp(a) - e;
+  if (va <= 0)
+  {
+    if (signe(gel(a,4))) return NULL;
+    /* all accuracy lost */
+    a = cvtop(remii(gel(x,4),p), p, 1);
+  }
+  else
+  {
+    setvalp(a, va); /* divide by p^e */
+    a = Qp_exp_safe(a);
+    if (!a) return NULL;
+    /* n=p^e and a^n=z*x where z is a (p-1)th-root of 1.
+     * Since z^n=z, we have (a/z)^n = x. */
+    a = gdiv(x, powgi(a,addis(n,-1))); /* = a/z = x/a^(n-1)*/
+    if (v) setvalp(a,v);
   }
-  /*If p=2 -1 is an root of unity in U1,we need an extra check*/
-  if (lgefint(p)==3 && p[2]==2 && mod8(gel(x,4))!=signe(gel(x,4)))
-    return NULL;
-  a = Qp_exp_safe(gdiv(Qp_log(x), n));
-  if (!a) return NULL;
-  /*Here n=p^e and a^n=z*x where z is a (p-1)th-root of unity. Note that
-      z^p=z; hence for b = a/z, then b^n=x. We say b=x/a^(n-1)*/
-  a = gdiv(x, powgi(a,addis(n,-1))); if (v) setvalp(a,v);
   return gerepileupto(ltop,a);
 }
 
@@ -1316,9 +1341,9 @@ Qp_sqrtn(GEN x, GEN n, GEN *zetan)
   long e;
   if (!signe(x[4]))
   {
-    long m = itos(n);
+    q = divii(addis(n, valp(x)-1), n);
     if (zetan) *zetan = gen_1;
-    return zeropadic(p, (valp(x)+m-1)/m);
+    avma = av; return zeropadic(p, itos(q));
   }
   /* treat the ramified part using logarithms */
   e = Z_pvalrem(n, p, &q);
