@@ -11,7 +11,7 @@ ANY WARRANTY WHATSOEVER.
 
 Check the License for details. You should have received a copy of it, along
 with the package; see the file 'COPYING'. If not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
+Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA. */
 
 /*******************************************************************/
 /**                                                               **/
@@ -177,7 +177,8 @@ handle_texmacs_command(const char *s)
 }
 #else
 static void
-handle_texmacs_command(const char *s) { pari_err(talker, "readline not available"); }
+handle_texmacs_command(const char *s)
+{ (void)s;pari_err(talker, "readline not available"); }
 #endif
 
 /*******************************************************************/
@@ -843,7 +844,7 @@ gp_head(void)
 #endif
   print_version();
   pari_putc('\n');
-  center("Copyright (C) 2000-2011 The PARI Group");
+  center("Copyright (C) 2000-2013 The PARI Group");
   pari_putc('\n');
   print_text("PARI/GP is free software, covered by the GNU General Public \
 License, and comes WITHOUT ANY WARRANTY WHATSOEVER.");
