@@ -11,7 +11,7 @@ ANY WARRANTY WHATSOEVER.
 
 Check the License for details. You should have received a copy of it, along
 with the package; see the file 'COPYING'. If not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
+Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA. */
 
 /* Written by Vasili Burdo */
 
@@ -104,6 +104,7 @@ PARI_get_plot(long f)
 {
   HDC hdc;
   TEXTMETRIC tm;
+  (void) f;
   if (pari_plot.init) return;      /* pari_plot is already set */
 
   pari_plot.init    = 1;
