@@ -11,7 +11,7 @@ ANY WARRANTY WHATSOEVER.
 
 Check the License for details. You should have received a copy of it, along
 with the package; see the file 'COPYING'. If not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
+Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA. */
 
 /*******************************************************************/
 /*                                                                 */
@@ -30,7 +30,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
 #endif
 
 BEGINEXTERN
-#include <X11/Xlib.h>
+#include <X11/XKBlib.h>
 #include <X11/Xutil.h>
 #include <X11/Xos.h>
 #ifndef XK_c
@@ -254,15 +254,13 @@ EXIT:
       case KeyRelease:
         /* Mod4 == Super on "std" Linux */
         keystate = event.xkey.state & (ShiftMask|ControlMask|Mod1Mask|Mod4Mask);
-        switch (XKeycodeToKeysym(display, event.xkey.keycode, 0))
+        switch (XkbKeycodeToKeysym(display, event.xkey.keycode, 0,0))
         {
         case XK_q:
-          if (!keystate || keystate == ControlMask)
-            goto EXIT;
+          if (!keystate || keystate == ControlMask) goto EXIT;
           break;
         case XK_c:
-          if (keystate == ControlMask)
-            goto EXIT;
+          if (keystate == ControlMask) goto EXIT;
           break;
         }
         break;
