@@ -11,7 +11,7 @@ ANY WARRANTY WHATSOEVER.
 
 Check the License for details. You should have received a copy of it, along
 with the package; see the file 'COPYING'. If not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
+Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA. */
 
 BEGINEXTERN
 /* hashtables */
@@ -252,7 +252,7 @@ int  gp_init_functions(void);
 GEN  pari_compile_str(char *lex, int strict);
 
 void pari_sigint(const char *s);
-pariFILE *pari_last_tmp_file();
+pariFILE *pari_last_tmp_file(void);
 void* get_stack(double fraction, long min);
 void  init_graph(void);
 void  free_graph(void);
