@@ -12,7 +12,7 @@ ANY WARRANTY WHATSOEVER.
 
 Check the License for details. You should have received a copy of it, along
 with the package; see the file 'COPYING'. If not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
+Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA. */
 
 /***********************************************************************/
 /**                                                                   **/
@@ -1473,11 +1473,11 @@ muliifft_unspliti(GEN V, long bs, long len)
       GEN up = int_LSW(u);
       long lu = NLIMBS(u);
       LOCAL_OVERFLOW;
-      *ap-- = addll(*ap, *up--);
+      *ap = addll(*ap, *up--); ap--;
       for (j=1; j<lu; j++)
-        *ap-- = addllx(*ap, *up--);
+       { *ap = addllx(*ap, *up--); ap--; }
       while (overflow)
-        *ap-- = addll(*ap, 1);
+       { *ap = addll(*ap, 1); ap--; }
     }
   }
   return int_normalize(a,0);
