@@ -11,7 +11,7 @@ ANY WARRANTY WHATSOEVER.
 
 Check the License for details. You should have received a copy of it, along
 with the package; see the file 'COPYING'. If not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
+Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA. */
 
 #include "pari.h"
 #include "paripriv.h"
@@ -190,11 +190,14 @@ entree oldfonctions[]={
 {"_^_",0,(void*)gpow,13,"GGp","_^_"},
 {"_^s",0,(void*)gpowgs,13,"GL","_^s"},
 {"__",0,NULL,13,NULL,"__"},
+{"_derivfun",0,(void*)derivfun0,15,"GGp","_derivfun(closure,[args]) numerical derivation of closure with respect to the first variable at (args)."},
+{"_eval_mnemonic",0,(void*)eval_mnemonic,15,"lGs","Convert a mnemonic string to a flag."},
 {"_void_if",0,(void*)ifpari_void,11,"vGDIDI","internal variant of if() that does not return a value."},
 {"_||_",0,(void*)orpari,13,"GE","x||y"},
 {"_~",0,(void*)gtrans,13,"G","_~"},
 {"O",0,(void*)ggrando,7,"GD1,L,","O(a^b): p-adic or power series zero with precision given by b."},
 {"O(_^_)",0,(void*)ggrando,7,"GD1,L,","O(a^b): p-adic or power series zero with precision given by b."},
+{"Str",0,(void*)Str,2,"s*","Str({x}*): concatenates its (string) argument into a single string."},
 {"abs",1,(void*)gabs,3,"Gp","abs(x)=absolute value (or modulus) of x."},
 {"acos",1,(void*)gacos,3,"Gp","acos(x)=inverse cosine of x."},
 {"acosh",1,(void*)gach,3,"Gp","acosh(x)=inverse hyperbolic cosine of x."},
