@@ -10,7 +10,7 @@ ANY WARRANTY WHATSOEVER.
 
 Check the License for details. You should have received a copy of it, along
 with the package; see the file 'COPYING'. If not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
+Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA. */
 
 #include "pari.h"
 #include "paripriv.h"
@@ -1062,8 +1062,9 @@ closure_eval(GEN C)
       break;
     case OClocalvar:
       {
-        entree *ep = (entree *)operand;
         long n = stack_new(&s_lvars);
+        entree *ep = (entree *)operand;
+        checkvalue(ep);
         lvars[n] = ep;
         nblvar++;
         pushvalue(ep,gel(st,--sp));
@@ -1071,8 +1072,9 @@ closure_eval(GEN C)
       }
     case OClocalvar0:
       {
-        entree *ep = (entree *)operand;
         long n = stack_new(&s_lvars);
+        entree *ep = (entree *)operand;
+        checkvalue(ep);
         lvars[n] = ep;
         nblvar++;
         zerovalue(ep);
@@ -1164,10 +1166,14 @@ closure_eval(GEN C)
         GEN z;
         if (typ(fun)!=t_CLOSURE) pari_err(notfuncer, fun);
         arity=fun[1];
-        if (n>arity)
-          pari_err(talker,"too many parameters in user-defined function call");
-        for (j=n+1;j<=arity;j++)
-          gel(st,sp++)=0;
+        if (n!=arity)
+        {
+          if (n>arity)
+            pari_err(talker,"too many parameters in user-defined function call");
+          st_alloc(arity-n);
+          for (j=n+1;j<=arity;j++)
+            gel(st,sp++)=0;
+        }
 #ifdef STACK_CHECK
         if (PARI_stack_limit && (void*) &z <= PARI_stack_limit)
           pari_err(talker, "deep recursion");
