@@ -11,7 +11,7 @@ ANY WARRANTY WHATSOEVER.
 
 Check the License for details. You should have received a copy of it, along
 with the package; see the file 'COPYING'. If not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
+Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA. */
 
 /*******************************************************************/
 /*                                                                 */
@@ -35,7 +35,7 @@ const double LOG2_10 = 3.321928094887362;  /* log_2(10) */
 
 GEN     gnil, gen_0, gen_1, gen_m1, gen_2, gen_m2, ghalf;
 
-static const long readonly_constants[] = {
+static const ulong readonly_constants[] = {
   evaltyp(t_INT) | _evallg(2),  /* gen_0 */
   evallgefint(2),
   evaltyp(t_INT) | _evallg(2),  /* gnil */
@@ -53,10 +53,10 @@ static const long readonly_constants[] = {
   evalsigne(-1) | evallgefint(3),
   2,
 };
-static const long readonly_ghalf[] = {
+static const ulong readonly_ghalf[] = {
   evaltyp(t_FRAC) | _evallg(3), /* ghalf */
-  (long)(readonly_constants+4),
-  (long)(readonly_constants+7)
+  (ulong)(readonly_constants+4),
+  (ulong)(readonly_constants+7)
 };
 THREAD GEN    bernzone;
 GEN     primetab; /* private primetable */
@@ -261,7 +261,7 @@ pari_stackcheck_init(void *stack_base)
 void
 pari_stackcheck_init(void *stack_base)
 {
-  PARI_stack_limit = NULL;
+  (void) stack_base; PARI_stack_limit = NULL;
 }
 #endif /* STACK_CHECK */
 
@@ -455,11 +455,12 @@ init_universal_constants(void)
   ghalf  = (GEN)readonly_ghalf;
 }
 
+static const size_t MIN_STACK = 500032;
 static size_t
 fix_size(size_t a)
 {
-  size_t b = (a / sizeof(long)) * sizeof(long); /* Align */
-  if (b < 1024) b = 1024;
+  size_t b = a & (~0x3fUL); /* Align */
+  if (b < MIN_STACK) b = MIN_STACK;
   return b;
 }
 /* old = current stack size (0 = unallocated), size = new size */
@@ -468,14 +469,15 @@ pari_init_stack(size_t size, size_t old)
 {
   size_t s = fix_size(size);
   if (old != s) {
-    if (old) pari_free((void*)bot);
     BLOCK_SIGINT_START;
+    if (old) pari_free((void*)bot);
     for (;; s>>=1)
     {
       char buf[128];
+      if (s < MIN_STACK) pari_err(memer); /* no way out. Die */
+      s = fix_size(s);
       bot = (pari_sp)malloc(s); /* NOT pari_malloc, memer would be deadly */
       if (bot) break;
-      if (!s) pari_err(memer); /* no way out. Die */
       /* must use sprintf: pari stack is currently dead */
       sprintf(buf, "not enough memory, new stack %lu", (ulong)s);
       pari_warn(warner, buf, s);
@@ -730,9 +732,9 @@ pari_init_opts(size_t parisize, ulong maxprime, ulong init_opts)
 
   pari_stackcheck_init(&u);
   if ((init_opts&INIT_DFTm)) {
+    pari_init_defaults();
     GP_DATA = default_gp_data();
     gp_expand_path(GP_DATA->path);
-    pari_init_defaults();
   }
 
   if ((init_opts&INIT_SIGm)) pari_sig_init(pari_sighandler);
@@ -778,6 +780,7 @@ pari_close_opts(ulong init_opts)
   pari_thread_close();
 
   free((void*)functions_hash);
+  free((void*)defaults_hash);
   free((void*)bot);
   free((void*)diffptr);
   free(current_logfile);
