@@ -91,10 +91,9 @@ ANY WARRANTY WHATSOEVER.
 
 Check the License for details. You should have received a copy of it, along
 with the package; see the file 'COPYING'. If not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
+Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA. */
 
 #define YYSIZE_T size_t
-#define YYERROR_VERBOSE 1
 #define YYSTYPE union token_value
 #define YYLTYPE struct node_loc
 #define YYLLOC_DEFAULT(Current, Rhs, N)     \
@@ -105,7 +104,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
 
 
 /* Line 189 of yacc.c  */
-#line 109 "../src/language/parse.c"
+#line 108 "../src/language/parse.c"
 
 /* Enabling traces.  */
 #ifndef YYDEBUG
@@ -117,7 +116,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
 # undef YYERROR_VERBOSE
 # define YYERROR_VERBOSE 1
 #else
-# define YYERROR_VERBOSE 0
+# define YYERROR_VERBOSE 1
 #endif
 
 /* Enabling the token table.  */
@@ -194,7 +193,7 @@ typedef struct YYLTYPE
 
 
 /* Line 264 of yacc.c  */
-#line 198 "../src/language/parse.c"
+#line 197 "../src/language/parse.c"
 
 #ifdef short
 # undef short
@@ -1346,7 +1345,7 @@ yydestruct (yymsg, yytype, yyvaluep, yylocationp, lex)
 	{ pari_discarded++; };
 
 /* Line 1000 of yacc.c  */
-#line 1350 "../src/language/parse.c"
+#line 1349 "../src/language/parse.c"
 	break;
       case 64: /* "matrix_index" */
 
@@ -1355,7 +1354,7 @@ yydestruct (yymsg, yytype, yyvaluep, yylocationp, lex)
 	{ pari_discarded++; };
 
 /* Line 1000 of yacc.c  */
-#line 1359 "../src/language/parse.c"
+#line 1358 "../src/language/parse.c"
 	break;
       case 65: /* "backticks" */
 
@@ -1364,7 +1363,7 @@ yydestruct (yymsg, yytype, yyvaluep, yylocationp, lex)
 	{ pari_discarded++; };
 
 /* Line 1000 of yacc.c  */
-#line 1368 "../src/language/parse.c"
+#line 1367 "../src/language/parse.c"
 	break;
       case 66: /* "history" */
 
@@ -1373,7 +1372,7 @@ yydestruct (yymsg, yytype, yyvaluep, yylocationp, lex)
 	{ pari_discarded++; };
 
 /* Line 1000 of yacc.c  */
-#line 1377 "../src/language/parse.c"
+#line 1376 "../src/language/parse.c"
 	break;
       case 67: /* "expr" */
 
@@ -1382,7 +1381,7 @@ yydestruct (yymsg, yytype, yyvaluep, yylocationp, lex)
 	{ pari_discarded++; };
 
 /* Line 1000 of yacc.c  */
-#line 1386 "../src/language/parse.c"
+#line 1385 "../src/language/parse.c"
 	break;
       case 68: /* "lvalue" */
 
@@ -1391,7 +1390,7 @@ yydestruct (yymsg, yytype, yyvaluep, yylocationp, lex)
 	{ pari_discarded++; };
 
 /* Line 1000 of yacc.c  */
-#line 1395 "../src/language/parse.c"
+#line 1394 "../src/language/parse.c"
 	break;
       case 69: /* "matrixelts" */
 
@@ -1400,7 +1399,7 @@ yydestruct (yymsg, yytype, yyvaluep, yylocationp, lex)
 	{ pari_discarded++; };
 
 /* Line 1000 of yacc.c  */
-#line 1404 "../src/language/parse.c"
+#line 1403 "../src/language/parse.c"
 	break;
       case 70: /* "matrixlines" */
 
@@ -1409,7 +1408,7 @@ yydestruct (yymsg, yytype, yyvaluep, yylocationp, lex)
 	{ pari_discarded++; };
 
 /* Line 1000 of yacc.c  */
-#line 1413 "../src/language/parse.c"
+#line 1412 "../src/language/parse.c"
 	break;
       case 71: /* "matrix" */
 
@@ -1418,7 +1417,7 @@ yydestruct (yymsg, yytype, yyvaluep, yylocationp, lex)
 	{ pari_discarded++; };
 
 /* Line 1000 of yacc.c  */
-#line 1422 "../src/language/parse.c"
+#line 1421 "../src/language/parse.c"
 	break;
       case 72: /* "arg" */
 
@@ -1427,7 +1426,7 @@ yydestruct (yymsg, yytype, yyvaluep, yylocationp, lex)
 	{ pari_discarded++; };
 
 /* Line 1000 of yacc.c  */
-#line 1431 "../src/language/parse.c"
+#line 1430 "../src/language/parse.c"
 	break;
       case 74: /* "listarg" */
 
@@ -1436,7 +1435,7 @@ yydestruct (yymsg, yytype, yyvaluep, yylocationp, lex)
 	{ pari_discarded++; };
 
 /* Line 1000 of yacc.c  */
-#line 1440 "../src/language/parse.c"
+#line 1439 "../src/language/parse.c"
 	break;
       case 75: /* "funcid" */
 
@@ -1445,7 +1444,7 @@ yydestruct (yymsg, yytype, yyvaluep, yylocationp, lex)
 	{ pari_discarded++; };
 
 /* Line 1000 of yacc.c  */
-#line 1449 "../src/language/parse.c"
+#line 1448 "../src/language/parse.c"
 	break;
       case 76: /* "memberid" */
 
@@ -1454,7 +1453,7 @@ yydestruct (yymsg, yytype, yyvaluep, yylocationp, lex)
 	{ pari_discarded++; };
 
 /* Line 1000 of yacc.c  */
-#line 1458 "../src/language/parse.c"
+#line 1457 "../src/language/parse.c"
 	break;
       case 77: /* "definition" */
 
@@ -1463,7 +1462,7 @@ yydestruct (yymsg, yytype, yyvaluep, yylocationp, lex)
 	{ pari_discarded++; };
 
 /* Line 1000 of yacc.c  */
-#line 1467 "../src/language/parse.c"
+#line 1466 "../src/language/parse.c"
 	break;
 
       default:
@@ -1616,7 +1615,7 @@ YYLTYPE yylloc;
 { yylloc.start=yylloc.end=*lex; }
 
 /* Line 1242 of yacc.c  */
-#line 1620 "../src/language/parse.c"
+#line 1619 "../src/language/parse.c"
   yylsp[0] = yylloc;
 
   goto yysetstate;
@@ -2470,7 +2469,7 @@ yyreduce:
 
 
 /* Line 1455 of yacc.c  */
-#line 2474 "../src/language/parse.c"
+#line 2473 "../src/language/parse.c"
       default: break;
     }
   YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);
