@@ -11,7 +11,7 @@ ANY WARRANTY WHATSOEVER.
 
 Check the License for details. You should have received a copy of it, along
 with the package; see the file 'COPYING'. If not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
+Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA. */
 
 /* This file is a C version by Bill Allombert of the 'ellsea' GP package
  * whose copyright statement is as follows:
@@ -105,7 +105,11 @@ ellmodulareqn(long ell, long vx, long vy)
   res = cgetg(3, t_VEC);
   if (!get_modular_eqn(&meqn, ell, vx, vy))
     pari_err(talker,"modular equation of level %ld is not available", ell);
-  gel(res,1) = meqn.eq; gel(res,2) = stoi(meqn.type=='A');
+  else
+  {
+    gel(res,1) = meqn.eq;
+    gel(res,2) = stoi(meqn.type=='A');
+  }
   return res;
 }
 
