@@ -11,7 +11,7 @@ ANY WARRANTY WHATSOEVER.
 
 Check the License for details. You should have received a copy of it, along
 with the package; see the file 'COPYING'. If not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
+Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA. */
 
 /**************************************************************/
 /*                                                            */
@@ -2202,8 +2202,8 @@ closure11(long EVEN, buildroot *BR)
     if (degpol(r) == 22) return 2; /* D11 */
     h = leafcopy(h); setvarn(h, MAXVARN);
     setvarn(r, 0); r = nffactor(h, r);
-    /* S11 of F_110[11] */
-    if (lg(r[1]) == 3) return 8; else return 4;
+    /* S11 (P10*P10*P90) or F_110[11] (11 factors of degree 10) */
+    return (lg(r[1])-1 == 11)? 4: 8;
   }
 }
 
@@ -2318,7 +2318,8 @@ isin_G_H(buildroot *BR, long n1, long n2)
   ww = check_isin(BR, &R, tau, ss);
   if (ww)
   {
-    long z[NMAX+1], i , j, l = lg(BR->r);
+    GEN z = cgetg(N+1, t_VEC);
+    long i, j, l = lg(BR->r);
     s0 = permmul(ww, s0);
     if (DEBUGLEVEL)
     {
@@ -2329,8 +2330,8 @@ isin_G_H(buildroot *BR, long n1, long n2)
     for (i = 1; i < l; i++)
     {
       GEN p1 = gel(BR->r,i);
-      for (j=1; j<=N; j++) z[j] = p1[(int)s0[j]];
-      for (j=1; j<=N; j++) p1[j] = z[j];
+      for (j=1; j<=N; j++) gel(z,j) = gel(p1, (int)s0[j]);
+      for (j=1; j<=N; j++) gel(p1,j) = gel(z,j);
     }
     avma = av; return n2;
   }
