@@ -10,7 +10,7 @@
 #  ifndef MPQS_DEBUG
 #  define MPQS_DEBUG
 #  endif
-#  define PRINT_IF_VERBOSE(x) fprintferr(x)
+#  define PRINT_IF_VERBOSE(x) err_printf(x)
 #else
 #  define PRINT_IF_VERBOSE(x)
 #endif
@@ -44,13 +44,9 @@
 /* following must be in range of the cand_multipliers table below */
 #define MPQS_MULTIPLIER_SEARCH_DEPTH 5 /* how many primes to inspect per k */
 
-/* XXX this comment is now totally off base...
- * `large primes' must be smaller than
- *   max(MPQS_LP_BOUND, largest_FB_p) * MPQS_LP_FACTOR
- * - increased this with the idea of capping it at about 2^30
- * (XX but see comment in mpqs() where we actually use this: we take the
- * min, not the max)
- */
+/* `large primes' must be smaller than
+ *   min(MPQS_LP_BOUND, largest_FB_p) * MPQS_LP_FACTOR
+ * - increased this with the idea of capping it at about 2^30 */
 #define MPQS_LP_BOUND              12500000 /* works for 32 and 64bit */
 
 /* see mpqs_locate_A_range() for an explanation of the following.  I had
@@ -125,9 +121,10 @@ typedef union mpqs_FB_entry {
   char __pad[MPQS_FB_ENTRY_PAD];
   struct {
     mpqs_int32_t __p;           /* the prime p */
-    /* XX following two are not yet used: */
+    /* Following two are not yet used: */
     float __flogp;              /* its logarithm as a 4-byte float */
     mpqs_invp_t __invp;         /* 1/p mod 2^64 or 2^BITS_IN_LONG */
+
     mpqs_int32_t __start1;      /* representatives of the two APs mod p */
     mpqs_int32_t __start2;
     mpqs_uint32_t __sqrt_kN;    /* sqrt(kN) mod p */
@@ -147,7 +144,7 @@ typedef union mpqs_FB_entry {
 #define fbe_flags       __entry.__flags
 
 /* --- flag bits for fbe_flags: */
-/* XXX TODO! */
+/* TODO */
 
 #define MPQS_FBE_CLEAR       0x0 /* no flags */
 
@@ -173,7 +170,7 @@ typedef struct mpqs_multiplier {
   mpqs_uint32_t kp[MPQS_MAX_OMEGA_K]; /* prime factors of k, if any */
 } mpqs_multiplier_t;
 
-static mpqs_multiplier_t cand_multipliers[] = {
+static const mpqs_multiplier_t cand_multipliers[] = {
   {  1, 0, {  0,  0} },
   {  3, 1, {  3,  0} },
   {  5, 1, {  5,  0} },
@@ -245,13 +242,13 @@ typedef struct mqps_per_A_prime {
  * sizing restriction: at most 17 prime factors for A;  thus i will range
  * from 0 to at most 15.)  This wastes a little memory for smaller N but
  * makes it easier for compilers to generate efficient code. */
-/* XX At present, memory locality vis-a-vis accesses to this array is good
- * XX in the slow (new A) branch of mpqs_self_init(), but poor in the fast
- * XX (same A, new B) branch, which now loops over the outer array index,
- * XX reading just one field of each inner array each time through the FB
- * XX loop.  This doesn't really harm, but will improve one day when we do
- * XX segmented sieve arrays with the associated segmented FB-range accesses.
- */
+
+/* NOTE: At present, memory locality vis-a-vis accesses to this array is good
+ * in the slow (new A) branch of mpqs_self_init(), but poor in the fast
+ * (same A, new B) branch, which now loops over the outer array index,
+ * reading just one field of each inner array each time through the FB
+ * loop.  This doesn't really harm, but will improve one day when we do
+ * segmented sieve arrays with the associated segmented FB-range accesses. */
 #define MPQS_MAX_OMEGA_A 17
 typedef struct mpqs_inv_A_H {
   mpqs_uint32_t _i[MPQS_MAX_OMEGA_A - 1];
@@ -264,7 +261,7 @@ typedef struct mpqs_inv_A_H {
  * wanting to keep the most frequently used stuff near the beginning. */
 
 typedef struct mpqs_handle {
-  /* pointers into gpmalloc()d memory which must be freed at the end: */
+  /* pointers into pari_malloc()d memory which must be freed at the end: */
   unsigned char *sieve_array;   /* 0-based, representing [-M,M-1] */
   unsigned char *sieve_array_end; /* points at sieve_array[M-1] */
   mpqs_FB_entry_t *FB;          /* (aligned) FB array itself */
@@ -289,7 +286,7 @@ typedef struct mpqs_handle {
   /* histogram feedback */
   unsigned char do_histograms;  /* (boolean) enable histogram updating */
   unsigned char done_histograms; /* histos have been eval'd for feedback */
-  /* more gpmalloc()d memory here: */
+  /* more pari_malloc()d memory here: */
   long *histo_full;             /* distribution of full rels from sieve */
   long *histo_lprl;             /* - of LP rels from sieve */
   long *histo_drop;             /* - of useless candidates */
@@ -311,20 +308,20 @@ typedef struct mpqs_handle {
   mpqs_uint32_t bin_index;      /* bit pattern for selecting primes for A */
   mpqs_uint32_t index_i;        /* running count of A's */
   mpqs_uint32_t index_j;        /* B's ordinal number in A's cohort */
-  /* XXX one more to follow here... */
+  /* TODO: one more to follow here... */
 
   /* further sizing parameters: */
   mpqs_int32_t target_no_rels;  /* target number of full relations */
   mpqs_int32_t largest_FB_p;    /* largest prime in the FB */
-  mpqs_int32_t pmin_index1;	/* lower bound for primes used for sieving */
+  mpqs_int32_t pmin_index1;        /* lower bound for primes used for sieving */
   mpqs_int32_t lp_scale;        /* factor by which LPs may exceed FB primes */
 
   mpqs_int32_t first_sort_point; /* when to sort and combine */
   mpqs_int32_t sort_pt_interval; /* (in units of 1/1000) */
 
-  /* XXX subscripts determining where to pick primes for A... */
+  /* subscripts determining where to pick primes for A... */
 
-  /* XX lp_bound might have to be mpqs_int64_t ? or mpqs_invp_t ? */
+  /* FIXME: lp_bound might have to be mpqs_int64_t ? or mpqs_invp_t ? */
   long lp_bound;                /* cutoff for Large Primes */
   long digit_size_N;
   long digit_size_kN;
@@ -333,9 +330,9 @@ typedef struct mpqs_handle {
   double dkN;                   /* - double prec. approximation of kN */
   double l2sqrtkN;              /* ~log2(sqrt(kN)) */
   double l2M;                   /* ~log2(M) (cf. below) */
-  /* XX need an index2_FB here to remember where to start picking primes */
+  /* TODO: need an index2_FB here to remember where to start picking primes */
 
-  /* XX put statistics here or keep them as local variables in mpqs() ? */
+  /* Put statistics here ? Currently keep them as local variables in mpqs() */
 
   /* bookkeeping pointers to containers of aligned memory chunks: */
   void *FB_chunk;               /* (unaligned) chunk containing the FB */
@@ -343,10 +340,6 @@ typedef struct mpqs_handle {
 
 } mpqs_handle_t;
 
-/* -- for Gauss/Lanczos */
-typedef ulong *F2_row;
-typedef F2_row *F2_matrix;
-
 /* -- sizing table entries */
 
 /* The "tolerance" is explained below apropos of mpqs_set_sieve_threshold().
@@ -394,7 +387,7 @@ typedef struct mpqs_parameterset {
 
 /* indexed by size of kN in decimal digits, subscript 0 corresponding to
  * 9 (or fewer) digits */
-static mpqs_parameterset_t mpqs_parameters[] =
+static const mpqs_parameterset_t mpqs_parameters[] =
 { /*       tol lp_scl     M   szFB  oA pmx1 1st  sti */
   {  /*9*/ 0.8,   1,    900,    20,  3,   5, 70,  8},
   { /*10*/ 0.8,   1,    900,    21,  3,   5, 70,  8},
