@@ -11,7 +11,7 @@ ANY WARRANTY WHATSOEVER.
 
 Check the License for details. You should have received a copy of it, along
 with the package; see the file 'COPYING'. If not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
+Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA. */
 
 #include "pari.h"
 #include "paripriv.h"
@@ -460,17 +460,18 @@ CheckSol(GEN *pS, GEN z1, GEN z2, GEN P, GEN rhs, GEN ro)
 static GEN
 GuessQi(GEN b, GEN c, GEN *eps)
 {
-  GEN Q, Lat, C = int2n(33);
+  const long shift = 33;
+  GEN Q, Lat, C = int2n(shift);
 
   Lat = matid(3);
-  gcoeff(Lat,3,1) = C;
-  gcoeff(Lat,3,2) = ground(gmul(C,b));
-  gcoeff(Lat,3,3) = ground(gmul(C,c));
+  gcoeff(Lat,3,1) = ground(gmul2n(b, shift));
+  gcoeff(Lat,3,2) = ground(gmul2n(c, shift));
+  gcoeff(Lat,3,3) = C;
 
   Q = gel(lllint(Lat),1);
-  if (gequal0(gel(Q,3))) return NULL; /* FAIL */
+  if (gequal0(gel(Q,2))) return NULL; /* FAIL */
 
-  *eps = gadd(gadd(gel(Q,1), gmul(gel(Q,2),b)), gmul(gel(Q,3),c));
+  *eps = gadd(gadd(gel(Q,3), gmul(gel(Q,1),b)), gmul(gel(Q,2),c));
   *eps = mpabs(*eps); return Q;
 }
 
@@ -478,9 +479,12 @@ GuessQi(GEN b, GEN c, GEN *eps)
 static GEN
 MiddleSols(GEN *pS, GEN bound, GEN roo, GEN poly, GEN rhs, long s, GEN c1)
 {
-  long j, k, nmax, d = degpol(poly);
-  GEN bndcf = sqrtnr(shiftr(c1,1), d - 2);
+  long j, k, nmax, d;
+  GEN bndcf;
 
+  if (expo(bound) < 0) return bound;
+  d = degpol(poly);
+  bndcf = sqrtnr(shiftr(c1,1), d - 2);
   if (cmprr(bound, bndcf) < 0) return bound;
   /* divide by log((1+sqrt(5))/2)
    * 1 + ==> ceil
@@ -625,10 +629,11 @@ thueinit(GEN pol, long flag, long prec)
 {
   GEN POL, C, L, fa, tnf, bnf = NULL;
   pari_sp av = avma;
-  long k, s, lfa, dpol = degpol(pol);
+  long k, s, lfa, dpol;
 
   if (checktnf(pol)) { bnf = checkbnf(gel(pol,2)); pol = gel(pol,1); }
   if (typ(pol)!=t_POL) pari_err(notpoler,"thueinit");
+  dpol = degpol(pol);
   if (dpol <= 0) pari_err(constpoler,"thueinit");
   RgX_check_ZX(pol, "thueinit");
   if (varn(pol)) { pol = leafcopy(pol); setvarn(pol, 0); }
@@ -649,7 +654,7 @@ thueinit(GEN pol, long flag, long prec)
     if (e != 1)
     {
       if (lfa == 2) {
-        tnf = mkvec2(thueinit(f, flag, prec), E);
+        tnf = mkvec2(mkvec3(pol,C,L), mkvec2(thueinit(f, flag, prec), E));
         return gerepilecopy(av, tnf);
       }
       P = gpowgs(f,e);
@@ -741,7 +746,7 @@ static GEN
 get_B0(long i1, GEN Delta, GEN Lambda, GEN eps5, long prec, baker_s *BS)
 {
   GEN B0 = Baker(BS);
-  long i2 = (i1 == 1)? 2: 1;
+  long step = 0, i2 = (i1 == 1)? 2: 1;
   for(;;) /* i2 from 1 to r unless r = 1 [then i2 = 2] */
   {
     init_get_B(i1,i2, Delta,Lambda,eps5, BS, prec);
@@ -759,22 +764,23 @@ get_B0(long i1, GEN Delta, GEN Lambda, GEN eps5, long prec, baker_s *BS)
         if (res) break;
         if (DEBUGLEVEL>1) err_printf("CF failed. Increasing kappa\n");
       }
-      if (cf == 10)
+      if (!step && cf == 10)
       { /* Semirational or totally rational case */
         GEN Q, ep, q, l0, denbound;
 
         if (! (Q = GuessQi(BS->delta, BS->lambda, &ep)) ) break;
 
-        denbound = gadd(B0, absi(gel(Q,2)));
+        denbound = gadd(B0, absi(gel(Q,1)));
         q = denom( bestappr(BS->delta, denbound) );
         l0 = subrr(errnum(BS->delta, q), ep);
         if (signe(l0) <= 0) break;
 
-        B0 = divrr(mplog(divrr(mulir(gel(Q,3), BS->c15), l0)),  BS->c13);
+        B0 = divrr(mplog(divrr(mulir(gel(Q,2), BS->c15), l0)),  BS->c13);
         if (DEBUGLEVEL>1) err_printf("Semirat. reduction: B0 -> %Ps\n",B0);
       }
       /* if no progress, stop */
       if (gcmp(oldB0, gadd(B0,dbltor(0.1))) <= 0) return gmin(oldB0, B0);
+      else step++;
     }
     i2++; if (i2 == i1) i2++;
     if (i2 > BS->r) break;
@@ -787,7 +793,7 @@ static GEN
 get_Bx_LLL(long i1, GEN Delta, GEN Lambda, GEN eps5, long prec, baker_s *BS)
 {
   GEN B0 = Baker(BS), Bx = NULL;
-  long i2 = (i1 == 1)? 2: 1;
+  long step = 0, i2 = (i1 == 1)? 2: 1;
   for(;;) /* i2 from 1 to r unless r = 1 [then i2 = 2] */
   {
     init_get_B(i1,i2, Delta,Lambda,eps5, BS, prec);
@@ -806,17 +812,17 @@ get_Bx_LLL(long i1, GEN Delta, GEN Lambda, GEN eps5, long prec, baker_s *BS)
       }
 
       /* FIXME: TO BE COMPLETED */
-      if (cf == 10)
+      if (!step && cf == 10)
       { /* Semirational or totally rational case */
         GEN Q, ep, q, l0, denbound;
 
         if (! (Q = GuessQi(BS->delta, BS->lambda, &ep)) ) break;
 
         /* Beware Q[2]] = gen_0 */
-        denbound = gadd(mulri(B0, absi(gel(Q,2))),
-                        mulii(BS->Ind, absi(gel(Q,3))));
+        denbound = gadd(mulri(B0, absi(gel(Q,1))),
+                        mulii(BS->Ind, absi(gel(Q,2))));
         q = denom( bestappr(BS->delta, denbound) );
-        l0 = divri(subrr(errnum(BS->delta, q), ep), absi(gel(Q,3)));
+        l0 = divri(subrr(errnum(BS->delta, q), ep), absi(gel(Q,2)));
         if (signe(l0) <= 0) break;
 
         get_B0Bx(BS, l0, &B0, &Bx);
@@ -824,7 +830,7 @@ get_Bx_LLL(long i1, GEN Delta, GEN Lambda, GEN eps5, long prec, baker_s *BS)
           err_printf("Semirat. reduction: B0 -> %Ps x <= %Ps\n",B0, Bx);
       }
       /* if no progress, stop */
-      if (oldBx && gcmp(oldBx, Bx) <= 0) return oldBx;
+      if (oldBx && gcmp(oldBx, Bx) <= 0) return oldBx; else step++;
     }
     i2++; if (i2 == i1) i2++;
     if (i2 > BS->r) break;
@@ -998,7 +1004,7 @@ LargeSols(GEN P, GEN tnf, GEN rhs, GEN ne, GEN *pS)
       }
     }
   }
-  return MiddleSols(pS, x3, ro, P, rhs, s, c1);
+  return gmax(x0, MiddleSols(pS, x3, ro, P, rhs, s, c1));
 
 PRECPB:
   ne = gerepilecopy(av, ne);
@@ -1055,9 +1061,19 @@ thue(GEN tnf, GEN rhs, GEN ne)
     if (!x3) { avma = (pari_sp)S; return S; }
     S = SmallSols(S, x3, POL, rhs);
   }
-  else if (typ(gel(tnf,2)) == t_INT) /* reducible case, pure power*/
+  else if (typ(gel(tnf,2)) == t_REAL)
+  { /* Case s=0. All solutions are "small". */
+    GEN c0 = gel(tnf,2); /* t_REAL */
+    if (!signe(rhs)) { avma = av; return sol_0(); }
+    x3 = sqrtnr(mulir(absi(rhs),c0), degpol(POL));
+    x3 = addrr(x3, dbltor(0.1)); /* guard from round-off errors */
+    S = SmallSols(S, x3, POL, rhs);
+  }
+  else if (typ(gmael(tnf,2,1)) == t_VEC) /* reducible case, pure power*/
   {
-    long e = itos( gel(tnf,2) );
+    long e;
+    tnf = gel(tnf,2);
+    e = itos( gel(tnf,2) );
     if (!signe(rhs)) { avma = av; return sol_0(); }
 
     if (!Z_ispowerall(rhs, e, &rhs)) { avma = av; return cgetg(1, t_VEC); }
@@ -1095,14 +1111,6 @@ thue(GEN tnf, GEN rhs, GEN ne)
       }
     }
   }
-  else
-  { /* Case s=0. All solutions are "small". */
-    GEN c0 = gel(tnf,2); /* t_REAL */
-    if (!signe(rhs)) { avma = av; return sol_0(); }
-    x3 = sqrtnr(mulir(absi(rhs),c0), degpol(POL));
-    x3 = addrr(x3, dbltor(0.1)); /* guard from round-off errors */
-    S = SmallSols(S, x3, POL, rhs);
-  }
   return gerepilecopy(av, filter_sol_x(S, L));
 }
 
